# pulp_container_client

PulpContainerClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 2.2.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_container_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_container_client-2.2.0.gem
```

(for development, run `gem install --dev ./pulp_container_client-2.2.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_container_client', '~> 2.2.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_container_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_container_client'

# Setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpContainerClient::ContentBlobsApi.new
opts = {
  digest: 'digest_example', # String | digest
  digest__in: 'digest__in_example', # String | digest__in
  limit: 56, # Integer | Number of results to return per page.
  media_type: 'media_type_example', # String | media_type
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | repository_version
  repository_version_added: 'repository_version_added_example', # String | repository_version_added
  repository_version_removed: 'repository_version_removed_example', # String | repository_version_removed
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List blobs
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling ContentBlobsApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpContainerClient::ContentBlobsApi* | [**list**](docs/ContentBlobsApi.md#list) | **GET** /pulp/api/v3/content/container/blobs/ | List blobs
*PulpContainerClient::ContentBlobsApi* | [**read**](docs/ContentBlobsApi.md#read) | **GET** {container_blob_href} | Inspect a blob
*PulpContainerClient::ContentManifestsApi* | [**list**](docs/ContentManifestsApi.md#list) | **GET** /pulp/api/v3/content/container/manifests/ | List manifests
*PulpContainerClient::ContentManifestsApi* | [**read**](docs/ContentManifestsApi.md#read) | **GET** {container_manifest_href} | Inspect a manifest
*PulpContainerClient::ContentTagsApi* | [**list**](docs/ContentTagsApi.md#list) | **GET** /pulp/api/v3/content/container/tags/ | List tags
*PulpContainerClient::ContentTagsApi* | [**read**](docs/ContentTagsApi.md#read) | **GET** {container_tag_href} | Inspect a tag
*PulpContainerClient::ContentguardsContentRedirectApi* | [**create**](docs/ContentguardsContentRedirectApi.md#create) | **POST** /pulp/api/v3/contentguards/container/content_redirect/ | Create a content redirect content guard
*PulpContainerClient::ContentguardsContentRedirectApi* | [**delete**](docs/ContentguardsContentRedirectApi.md#delete) | **DELETE** {container_content_redirect_content_guard_href} | Delete a content redirect content guard
*PulpContainerClient::ContentguardsContentRedirectApi* | [**list**](docs/ContentguardsContentRedirectApi.md#list) | **GET** /pulp/api/v3/contentguards/container/content_redirect/ | List content redirect content guards
*PulpContainerClient::ContentguardsContentRedirectApi* | [**partial_update**](docs/ContentguardsContentRedirectApi.md#partial_update) | **PATCH** {container_content_redirect_content_guard_href} | Update a content redirect content guard
*PulpContainerClient::ContentguardsContentRedirectApi* | [**read**](docs/ContentguardsContentRedirectApi.md#read) | **GET** {container_content_redirect_content_guard_href} | Inspect a content redirect content guard
*PulpContainerClient::ContentguardsContentRedirectApi* | [**update**](docs/ContentguardsContentRedirectApi.md#update) | **PUT** {container_content_redirect_content_guard_href} | Update a content redirect content guard
*PulpContainerClient::DistributionsContainerApi* | [**create**](docs/DistributionsContainerApi.md#create) | **POST** /pulp/api/v3/distributions/container/container/ | Create a container distribution
*PulpContainerClient::DistributionsContainerApi* | [**delete**](docs/DistributionsContainerApi.md#delete) | **DELETE** {container_container_distribution_href} | Delete a container distribution
*PulpContainerClient::DistributionsContainerApi* | [**list**](docs/DistributionsContainerApi.md#list) | **GET** /pulp/api/v3/distributions/container/container/ | List container distributions
*PulpContainerClient::DistributionsContainerApi* | [**partial_update**](docs/DistributionsContainerApi.md#partial_update) | **PATCH** {container_container_distribution_href} | Update a container distribution
*PulpContainerClient::DistributionsContainerApi* | [**read**](docs/DistributionsContainerApi.md#read) | **GET** {container_container_distribution_href} | Inspect a container distribution
*PulpContainerClient::DistributionsContainerApi* | [**update**](docs/DistributionsContainerApi.md#update) | **PUT** {container_container_distribution_href} | Update a container distribution
*PulpContainerClient::PulpContainerNamespacesApi* | [**create**](docs/PulpContainerNamespacesApi.md#create) | **POST** /pulp/api/v3/pulp_container/namespaces/ | Create a container namespace
*PulpContainerClient::PulpContainerNamespacesApi* | [**delete**](docs/PulpContainerNamespacesApi.md#delete) | **DELETE** {container_container_namespace_href} | Delete a container namespace
*PulpContainerClient::PulpContainerNamespacesApi* | [**list**](docs/PulpContainerNamespacesApi.md#list) | **GET** /pulp/api/v3/pulp_container/namespaces/ | List container namespaces
*PulpContainerClient::PulpContainerNamespacesApi* | [**read**](docs/PulpContainerNamespacesApi.md#read) | **GET** {container_container_namespace_href} | Inspect a container namespace
*PulpContainerClient::RemotesContainerApi* | [**create**](docs/RemotesContainerApi.md#create) | **POST** /pulp/api/v3/remotes/container/container/ | Create a container remote
*PulpContainerClient::RemotesContainerApi* | [**delete**](docs/RemotesContainerApi.md#delete) | **DELETE** {container_container_remote_href} | Delete a container remote
*PulpContainerClient::RemotesContainerApi* | [**list**](docs/RemotesContainerApi.md#list) | **GET** /pulp/api/v3/remotes/container/container/ | List container remotes
*PulpContainerClient::RemotesContainerApi* | [**partial_update**](docs/RemotesContainerApi.md#partial_update) | **PATCH** {container_container_remote_href} | Update a container remote
*PulpContainerClient::RemotesContainerApi* | [**read**](docs/RemotesContainerApi.md#read) | **GET** {container_container_remote_href} | Inspect a container remote
*PulpContainerClient::RemotesContainerApi* | [**update**](docs/RemotesContainerApi.md#update) | **PUT** {container_container_remote_href} | Update a container remote
*PulpContainerClient::RepositoriesContainerApi* | [**add**](docs/RepositoriesContainerApi.md#add) | **POST** {container_container_repository_href}add/ | Add content
*PulpContainerClient::RepositoriesContainerApi* | [**build_image**](docs/RepositoriesContainerApi.md#build_image) | **POST** {container_container_repository_href}build_image/ | Build an Image
*PulpContainerClient::RepositoriesContainerApi* | [**copy_manifests**](docs/RepositoriesContainerApi.md#copy_manifests) | **POST** {container_container_repository_href}copy_manifests/ | Copy manifests
*PulpContainerClient::RepositoriesContainerApi* | [**copy_tags**](docs/RepositoriesContainerApi.md#copy_tags) | **POST** {container_container_repository_href}copy_tags/ | Copy tags
*PulpContainerClient::RepositoriesContainerApi* | [**create**](docs/RepositoriesContainerApi.md#create) | **POST** /pulp/api/v3/repositories/container/container/ | Create a container repository
*PulpContainerClient::RepositoriesContainerApi* | [**delete**](docs/RepositoriesContainerApi.md#delete) | **DELETE** {container_container_repository_href} | Delete a container repository
*PulpContainerClient::RepositoriesContainerApi* | [**list**](docs/RepositoriesContainerApi.md#list) | **GET** /pulp/api/v3/repositories/container/container/ | List container repositorys
*PulpContainerClient::RepositoriesContainerApi* | [**partial_update**](docs/RepositoriesContainerApi.md#partial_update) | **PATCH** {container_container_repository_href} | Update a container repository
*PulpContainerClient::RepositoriesContainerApi* | [**read**](docs/RepositoriesContainerApi.md#read) | **GET** {container_container_repository_href} | Inspect a container repository
*PulpContainerClient::RepositoriesContainerApi* | [**remove**](docs/RepositoriesContainerApi.md#remove) | **POST** {container_container_repository_href}remove/ | Remove content
*PulpContainerClient::RepositoriesContainerApi* | [**sync**](docs/RepositoriesContainerApi.md#sync) | **POST** {container_container_repository_href}sync/ | Sync from a remote
*PulpContainerClient::RepositoriesContainerApi* | [**tag**](docs/RepositoriesContainerApi.md#tag) | **POST** {container_container_repository_href}tag/ | Create a Tag
*PulpContainerClient::RepositoriesContainerApi* | [**untag**](docs/RepositoriesContainerApi.md#untag) | **POST** {container_container_repository_href}untag/ | Delete a tag
*PulpContainerClient::RepositoriesContainerApi* | [**update**](docs/RepositoriesContainerApi.md#update) | **PUT** {container_container_repository_href} | Update a container repository
*PulpContainerClient::RepositoriesContainerPushApi* | [**create**](docs/RepositoriesContainerPushApi.md#create) | **POST** /pulp/api/v3/repositories/container/container-push/ | Create a container push repository
*PulpContainerClient::RepositoriesContainerPushApi* | [**delete**](docs/RepositoriesContainerPushApi.md#delete) | **DELETE** {container_container_push_repository_href} | Delete a container push repository
*PulpContainerClient::RepositoriesContainerPushApi* | [**list**](docs/RepositoriesContainerPushApi.md#list) | **GET** /pulp/api/v3/repositories/container/container-push/ | List container push repositorys
*PulpContainerClient::RepositoriesContainerPushApi* | [**read**](docs/RepositoriesContainerPushApi.md#read) | **GET** {container_container_push_repository_href} | Inspect a container push repository
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**delete**](docs/RepositoriesContainerVersionsApi.md#delete) | **DELETE** {container_container_push_repository_version_href} | Delete a repository version
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**delete_0**](docs/RepositoriesContainerVersionsApi.md#delete_0) | **DELETE** {container_container_repository_version_href} | Delete a repository version
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**list**](docs/RepositoriesContainerVersionsApi.md#list) | **GET** {container_container_push_repository_href}versions/ | List repository versions
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**list_0**](docs/RepositoriesContainerVersionsApi.md#list_0) | **GET** {container_container_repository_href}versions/ | List repository versions
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**read**](docs/RepositoriesContainerVersionsApi.md#read) | **GET** {container_container_push_repository_version_href} | Inspect a repository version
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**read_0**](docs/RepositoriesContainerVersionsApi.md#read_0) | **GET** {container_container_repository_version_href} | Inspect a repository version
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**repair**](docs/RepositoriesContainerVersionsApi.md#repair) | **POST** {container_container_push_repository_version_href}repair/ | 
*PulpContainerClient::RepositoriesContainerVersionsApi* | [**repair_0**](docs/RepositoriesContainerVersionsApi.md#repair_0) | **POST** {container_container_repository_version_href}repair/ | 
*PulpContainerClient::TokenApi* | [**get**](docs/TokenApi.md#get) | **GET** /token/ | 


## Documentation for Models

 - [PulpContainerClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpContainerClient::ContainerBlobResponse](docs/ContainerBlobResponse.md)
 - [PulpContainerClient::ContainerContainerDistribution](docs/ContainerContainerDistribution.md)
 - [PulpContainerClient::ContainerContainerDistributionResponse](docs/ContainerContainerDistributionResponse.md)
 - [PulpContainerClient::ContainerContainerNamespace](docs/ContainerContainerNamespace.md)
 - [PulpContainerClient::ContainerContainerNamespaceResponse](docs/ContainerContainerNamespaceResponse.md)
 - [PulpContainerClient::ContainerContainerPushRepository](docs/ContainerContainerPushRepository.md)
 - [PulpContainerClient::ContainerContainerPushRepositoryResponse](docs/ContainerContainerPushRepositoryResponse.md)
 - [PulpContainerClient::ContainerContainerRemote](docs/ContainerContainerRemote.md)
 - [PulpContainerClient::ContainerContainerRemoteResponse](docs/ContainerContainerRemoteResponse.md)
 - [PulpContainerClient::ContainerContainerRepository](docs/ContainerContainerRepository.md)
 - [PulpContainerClient::ContainerContainerRepositoryResponse](docs/ContainerContainerRepositoryResponse.md)
 - [PulpContainerClient::ContainerContentRedirectContentGuard](docs/ContainerContentRedirectContentGuard.md)
 - [PulpContainerClient::ContainerContentRedirectContentGuardResponse](docs/ContainerContentRedirectContentGuardResponse.md)
 - [PulpContainerClient::ContainerManifestResponse](docs/ContainerManifestResponse.md)
 - [PulpContainerClient::ContainerTagResponse](docs/ContainerTagResponse.md)
 - [PulpContainerClient::ContentSummary](docs/ContentSummary.md)
 - [PulpContainerClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpContainerClient::ManifestCopy](docs/ManifestCopy.md)
 - [PulpContainerClient::OCIBuildImage](docs/OCIBuildImage.md)
 - [PulpContainerClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpContainerClient::PaginatedcontainerBlobResponseList](docs/PaginatedcontainerBlobResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContainerDistributionResponseList](docs/PaginatedcontainerContainerDistributionResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContainerNamespaceResponseList](docs/PaginatedcontainerContainerNamespaceResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContainerPushRepositoryResponseList](docs/PaginatedcontainerContainerPushRepositoryResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContainerRemoteResponseList](docs/PaginatedcontainerContainerRemoteResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContainerRepositoryResponseList](docs/PaginatedcontainerContainerRepositoryResponseList.md)
 - [PulpContainerClient::PaginatedcontainerContentRedirectContentGuardResponseList](docs/PaginatedcontainerContentRedirectContentGuardResponseList.md)
 - [PulpContainerClient::PaginatedcontainerManifestResponseList](docs/PaginatedcontainerManifestResponseList.md)
 - [PulpContainerClient::PaginatedcontainerTagResponseList](docs/PaginatedcontainerTagResponseList.md)
 - [PulpContainerClient::PatchedcontainerContainerDistribution](docs/PatchedcontainerContainerDistribution.md)
 - [PulpContainerClient::PatchedcontainerContainerRemote](docs/PatchedcontainerContainerRemote.md)
 - [PulpContainerClient::PatchedcontainerContainerRepository](docs/PatchedcontainerContainerRepository.md)
 - [PulpContainerClient::PatchedcontainerContentRedirectContentGuard](docs/PatchedcontainerContentRedirectContentGuard.md)
 - [PulpContainerClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpContainerClient::RecursiveManage](docs/RecursiveManage.md)
 - [PulpContainerClient::RepositorySyncURL](docs/RepositorySyncURL.md)
 - [PulpContainerClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpContainerClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpContainerClient::TagCopy](docs/TagCopy.md)
 - [PulpContainerClient::TagImage](docs/TagImage.md)
 - [PulpContainerClient::UnTagImage](docs/UnTagImage.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

