# PulpContainerClient::DistributionsContainerApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsContainerApi.md#create) | **POST** /pulp/api/v3/distributions/container/container/ | Create a container distribution
[**delete**](DistributionsContainerApi.md#delete) | **DELETE** {container_container_distribution_href} | Delete a container distribution
[**list**](DistributionsContainerApi.md#list) | **GET** /pulp/api/v3/distributions/container/container/ | List container distributions
[**partial_update**](DistributionsContainerApi.md#partial_update) | **PATCH** {container_container_distribution_href} | Update a container distribution
[**read**](DistributionsContainerApi.md#read) | **GET** {container_container_distribution_href} | Inspect a container distribution
[**update**](DistributionsContainerApi.md#update) | **PUT** {container_container_distribution_href} | Update a container distribution



## create

> AsyncOperationResponse create(container_container_distribution)

Create a container distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
container_container_distribution = PulpContainerClient::ContainerContainerDistribution.new # ContainerContainerDistribution | 

begin
  #Create a container distribution
  result = api_instance.create(container_container_distribution)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_distribution** | [**ContainerContainerDistribution**](ContainerContainerDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(container_container_distribution_href)

Delete a container distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
container_container_distribution_href = 'container_container_distribution_href_example' # String | 

begin
  #Delete a container distribution
  result = api_instance.delete(container_container_distribution_href)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedcontainerContainerDistributionResponseList list(opts)

List container distributions

The Container Distribution will serve the latest version of a Repository if ``repository`` is specified. The Container Distribution will serve a specific repository version if ``repository_version``. Note that **either** ``repository`` or ``repository_version`` can be set on a Container Distribution, but not both.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
opts = {
  base_path: 'base_path_example', # String | base_path
  base_path__contains: 'base_path__contains_example', # String | base_path__contains
  base_path__icontains: 'base_path__icontains_example', # String | base_path__icontains
  base_path__in: 'base_path__in_example', # String | base_path__in
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  namespace__name: 'namespace__name_example', # String | namespace__name
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List container distributions
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**| base_path | [optional] 
 **base_path__contains** | **String**| base_path__contains | [optional] 
 **base_path__icontains** | **String**| base_path__icontains | [optional] 
 **base_path__in** | **String**| base_path__in | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **namespace__name** | **String**| namespace__name | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerContainerDistributionResponseList**](PaginatedcontainerContainerDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(container_container_distribution_href, patchedcontainer_container_distribution)

Update a container distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
container_container_distribution_href = 'container_container_distribution_href_example' # String | 
patchedcontainer_container_distribution = PulpContainerClient::PatchedcontainerContainerDistribution.new # PatchedcontainerContainerDistribution | 

begin
  #Update a container distribution
  result = api_instance.partial_update(container_container_distribution_href, patchedcontainer_container_distribution)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_distribution_href** | **String**|  | 
 **patchedcontainer_container_distribution** | [**PatchedcontainerContainerDistribution**](PatchedcontainerContainerDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> ContainerContainerDistributionResponse read(container_container_distribution_href, opts)

Inspect a container distribution

The Container Distribution will serve the latest version of a Repository if ``repository`` is specified. The Container Distribution will serve a specific repository version if ``repository_version``. Note that **either** ``repository`` or ``repository_version`` can be set on a Container Distribution, but not both.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
container_container_distribution_href = 'container_container_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a container distribution
  result = api_instance.read(container_container_distribution_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerContainerDistributionResponse**](ContainerContainerDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(container_container_distribution_href, container_container_distribution)

Update a container distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::DistributionsContainerApi.new
container_container_distribution_href = 'container_container_distribution_href_example' # String | 
container_container_distribution = PulpContainerClient::ContainerContainerDistribution.new # ContainerContainerDistribution | 

begin
  #Update a container distribution
  result = api_instance.update(container_container_distribution_href, container_container_distribution)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling DistributionsContainerApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_distribution_href** | **String**|  | 
 **container_container_distribution** | [**ContainerContainerDistribution**](ContainerContainerDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

