# PulpContainerClient::RemotesContainerApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesContainerApi.md#create) | **POST** /pulp/api/v3/remotes/container/container/ | Create a container remote
[**delete**](RemotesContainerApi.md#delete) | **DELETE** {container_container_remote_href} | Delete a container remote
[**list**](RemotesContainerApi.md#list) | **GET** /pulp/api/v3/remotes/container/container/ | List container remotes
[**partial_update**](RemotesContainerApi.md#partial_update) | **PATCH** {container_container_remote_href} | Update a container remote
[**read**](RemotesContainerApi.md#read) | **GET** {container_container_remote_href} | Inspect a container remote
[**update**](RemotesContainerApi.md#update) | **PUT** {container_container_remote_href} | Update a container remote



## create

> ContainerContainerRemoteResponse create(container_container_remote)

Create a container remote

Container remotes represent an external repository that implements the Container Registry API. Container remotes support deferred downloading by configuring the ``policy`` field.  ``on_demand`` and ``streamed`` policies can provide significant disk space savings.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
container_container_remote = PulpContainerClient::ContainerContainerRemote.new # ContainerContainerRemote | 

begin
  #Create a container remote
  result = api_instance.create(container_container_remote)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_remote** | [**ContainerContainerRemote**](ContainerContainerRemote.md)|  | 

### Return type

[**ContainerContainerRemoteResponse**](ContainerContainerRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(container_container_remote_href)

Delete a container remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
container_container_remote_href = 'container_container_remote_href_example' # String | 

begin
  #Delete a container remote
  result = api_instance.delete(container_container_remote_href)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedcontainerContainerRemoteResponseList list(opts)

List container remotes

Container remotes represent an external repository that implements the Container Registry API. Container remotes support deferred downloading by configuring the ``policy`` field.  ``on_demand`` and ``streamed`` policies can provide significant disk space savings.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_last_updated: 'pulp_last_updated_example', # String | pulp_last_updated
  pulp_last_updated__gt: 'pulp_last_updated__gt_example', # String | pulp_last_updated__gt
  pulp_last_updated__gte: 'pulp_last_updated__gte_example', # String | pulp_last_updated__gte
  pulp_last_updated__lt: 'pulp_last_updated__lt_example', # String | pulp_last_updated__lt
  pulp_last_updated__lte: 'pulp_last_updated__lte_example', # String | pulp_last_updated__lte
  pulp_last_updated__range: 'pulp_last_updated__range_example', # String | pulp_last_updated__range
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List container remotes
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_last_updated** | **String**| pulp_last_updated | [optional] 
 **pulp_last_updated__gt** | **String**| pulp_last_updated__gt | [optional] 
 **pulp_last_updated__gte** | **String**| pulp_last_updated__gte | [optional] 
 **pulp_last_updated__lt** | **String**| pulp_last_updated__lt | [optional] 
 **pulp_last_updated__lte** | **String**| pulp_last_updated__lte | [optional] 
 **pulp_last_updated__range** | **String**| pulp_last_updated__range | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerContainerRemoteResponseList**](PaginatedcontainerContainerRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(container_container_remote_href, patchedcontainer_container_remote)

Update a container remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
container_container_remote_href = 'container_container_remote_href_example' # String | 
patchedcontainer_container_remote = PulpContainerClient::PatchedcontainerContainerRemote.new # PatchedcontainerContainerRemote | 

begin
  #Update a container remote
  result = api_instance.partial_update(container_container_remote_href, patchedcontainer_container_remote)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_remote_href** | **String**|  | 
 **patchedcontainer_container_remote** | [**PatchedcontainerContainerRemote**](PatchedcontainerContainerRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> ContainerContainerRemoteResponse read(container_container_remote_href, opts)

Inspect a container remote

Container remotes represent an external repository that implements the Container Registry API. Container remotes support deferred downloading by configuring the ``policy`` field.  ``on_demand`` and ``streamed`` policies can provide significant disk space savings.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
container_container_remote_href = 'container_container_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a container remote
  result = api_instance.read(container_container_remote_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerContainerRemoteResponse**](ContainerContainerRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(container_container_remote_href, container_container_remote)

Update a container remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RemotesContainerApi.new
container_container_remote_href = 'container_container_remote_href_example' # String | 
container_container_remote = PulpContainerClient::ContainerContainerRemote.new # ContainerContainerRemote | 

begin
  #Update a container remote
  result = api_instance.update(container_container_remote_href, container_container_remote)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RemotesContainerApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_remote_href** | **String**|  | 
 **container_container_remote** | [**ContainerContainerRemote**](ContainerContainerRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

