# PulpContainerClient::RepositoriesContainerApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add**](RepositoriesContainerApi.md#add) | **POST** {container_container_repository_href}add/ | Add content
[**build_image**](RepositoriesContainerApi.md#build_image) | **POST** {container_container_repository_href}build_image/ | Build an Image
[**copy_manifests**](RepositoriesContainerApi.md#copy_manifests) | **POST** {container_container_repository_href}copy_manifests/ | Copy manifests
[**copy_tags**](RepositoriesContainerApi.md#copy_tags) | **POST** {container_container_repository_href}copy_tags/ | Copy tags
[**create**](RepositoriesContainerApi.md#create) | **POST** /pulp/api/v3/repositories/container/container/ | Create a container repository
[**delete**](RepositoriesContainerApi.md#delete) | **DELETE** {container_container_repository_href} | Delete a container repository
[**list**](RepositoriesContainerApi.md#list) | **GET** /pulp/api/v3/repositories/container/container/ | List container repositorys
[**partial_update**](RepositoriesContainerApi.md#partial_update) | **PATCH** {container_container_repository_href} | Update a container repository
[**read**](RepositoriesContainerApi.md#read) | **GET** {container_container_repository_href} | Inspect a container repository
[**remove**](RepositoriesContainerApi.md#remove) | **POST** {container_container_repository_href}remove/ | Remove content
[**sync**](RepositoriesContainerApi.md#sync) | **POST** {container_container_repository_href}sync/ | Sync from a remote
[**tag**](RepositoriesContainerApi.md#tag) | **POST** {container_container_repository_href}tag/ | Create a Tag
[**untag**](RepositoriesContainerApi.md#untag) | **POST** {container_container_repository_href}untag/ | Delete a tag
[**update**](RepositoriesContainerApi.md#update) | **PUT** {container_container_repository_href} | Update a container repository



## add

> AsyncOperationResponse add(container_container_repository_href, recursive_manage)

Add content

Trigger an asynchronous task to recursively add container content.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
recursive_manage = PulpContainerClient::RecursiveManage.new # RecursiveManage | 

begin
  #Add content
  result = api_instance.add(container_container_repository_href, recursive_manage)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->add: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **recursive_manage** | [**RecursiveManage**](RecursiveManage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## build_image

> AsyncOperationResponse build_image(container_container_repository_href, opts)

Build an Image

Trigger an asynchronous task to build an OCI image from a Containerfile. A new repository version is created with the new image and tag. This API is tech preview in Pulp Container 1.1. Backwards compatibility when upgrading is not guaranteed.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
opts = {
  containerfile_artifact: 'containerfile_artifact_example', # String | Artifact representing the Containerfile that should be used to run buildah.
  containerfile: File.new('/path/to/file'), # File | An uploaded Containerfile that should be used to run buildah.
  tag: 'latest', # String | A tag name for the new image being built.
  artifacts: nil # Object | A JSON string where each key is an artifact href and the value is it's relative path (name) inside the /pulp_working_directory of the build container executing the Containerfile.
}

begin
  #Build an Image
  result = api_instance.build_image(container_container_repository_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->build_image: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **containerfile_artifact** | **String**| Artifact representing the Containerfile that should be used to run buildah. | [optional] 
 **containerfile** | **File**| An uploaded Containerfile that should be used to run buildah. | [optional] 
 **tag** | **String**| A tag name for the new image being built. | [optional] [default to &#39;latest&#39;]
 **artifacts** | [**Object**](Object.md)| A JSON string where each key is an artifact href and the value is it&#39;s relative path (name) inside the /pulp_working_directory of the build container executing the Containerfile. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## copy_manifests

> AsyncOperationResponse copy_manifests(container_container_repository_href, manifest_copy)

Copy manifests

Trigger an asynchronous task to copy manifests

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
manifest_copy = PulpContainerClient::ManifestCopy.new # ManifestCopy | 

begin
  #Copy manifests
  result = api_instance.copy_manifests(container_container_repository_href, manifest_copy)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->copy_manifests: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **manifest_copy** | [**ManifestCopy**](ManifestCopy.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## copy_tags

> AsyncOperationResponse copy_tags(container_container_repository_href, tag_copy)

Copy tags

Trigger an asynchronous task to copy tags

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
tag_copy = PulpContainerClient::TagCopy.new # TagCopy | 

begin
  #Copy tags
  result = api_instance.copy_tags(container_container_repository_href, tag_copy)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->copy_tags: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **tag_copy** | [**TagCopy**](TagCopy.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## create

> ContainerContainerRepositoryResponse create(container_container_repository)

Create a container repository

ViewSet for container repo.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository = PulpContainerClient::ContainerContainerRepository.new # ContainerContainerRepository | 

begin
  #Create a container repository
  result = api_instance.create(container_container_repository)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository** | [**ContainerContainerRepository**](ContainerContainerRepository.md)|  | 

### Return type

[**ContainerContainerRepositoryResponse**](ContainerContainerRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(container_container_repository_href)

Delete a container repository

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 

begin
  #Delete a container repository
  result = api_instance.delete(container_container_repository_href)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedcontainerContainerRepositoryResponseList list(opts)

List container repositorys

ViewSet for container repo.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | name
  name__in: 'name__in_example', # String | name__in
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List container repositorys
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| name | [optional] 
 **name__in** | **String**| name__in | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerContainerRepositoryResponseList**](PaginatedcontainerContainerRepositoryResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(container_container_repository_href, patchedcontainer_container_repository)

Update a container repository

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
patchedcontainer_container_repository = PulpContainerClient::PatchedcontainerContainerRepository.new # PatchedcontainerContainerRepository | 

begin
  #Update a container repository
  result = api_instance.partial_update(container_container_repository_href, patchedcontainer_container_repository)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **patchedcontainer_container_repository** | [**PatchedcontainerContainerRepository**](PatchedcontainerContainerRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> ContainerContainerRepositoryResponse read(container_container_repository_href, opts)

Inspect a container repository

ViewSet for container repo.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a container repository
  result = api_instance.read(container_container_repository_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerContainerRepositoryResponse**](ContainerContainerRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## remove

> AsyncOperationResponse remove(container_container_repository_href, recursive_manage)

Remove content

Trigger an async task to recursively remove container content.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
recursive_manage = PulpContainerClient::RecursiveManage.new # RecursiveManage | 

begin
  #Remove content
  result = api_instance.remove(container_container_repository_href, recursive_manage)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->remove: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **recursive_manage** | [**RecursiveManage**](RecursiveManage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## sync

> AsyncOperationResponse sync(container_container_repository_href, repository_sync_url)

Sync from a remote

Trigger an asynchronous task to sync content.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
repository_sync_url = PulpContainerClient::RepositorySyncURL.new # RepositorySyncURL | 

begin
  #Sync from a remote
  result = api_instance.sync(container_container_repository_href, repository_sync_url)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->sync: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **repository_sync_url** | [**RepositorySyncURL**](RepositorySyncURL.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## tag

> AsyncOperationResponse tag(container_container_repository_href, tag_image)

Create a Tag

Trigger an asynchronous task to tag an image in the repository

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
tag_image = PulpContainerClient::TagImage.new # TagImage | 

begin
  #Create a Tag
  result = api_instance.tag(container_container_repository_href, tag_image)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->tag: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **tag_image** | [**TagImage**](TagImage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## untag

> AsyncOperationResponse untag(container_container_repository_href, un_tag_image)

Delete a tag

Trigger an asynchronous task to untag an image in the repository

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
un_tag_image = PulpContainerClient::UnTagImage.new # UnTagImage | 

begin
  #Delete a tag
  result = api_instance.untag(container_container_repository_href, un_tag_image)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->untag: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **un_tag_image** | [**UnTagImage**](UnTagImage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(container_container_repository_href, container_container_repository)

Update a container repository

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::RepositoriesContainerApi.new
container_container_repository_href = 'container_container_repository_href_example' # String | 
container_container_repository = PulpContainerClient::ContainerContainerRepository.new # ContainerContainerRepository | 

begin
  #Update a container repository
  result = api_instance.update(container_container_repository_href, container_container_repository)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling RepositoriesContainerApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_container_repository_href** | **String**|  | 
 **container_container_repository** | [**ContainerContainerRepository**](ContainerContainerRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

